package com.weather.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.weather.entity.WeaRotaInfo;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 产品存储ftp Mapper 接口
 * </p>
 *
 * @author feng
 * @since 2023-09-05
 */
public interface WeaRotaInfoMapper extends BaseMapper<WeaRotaInfo> {

    /**
     * 查询公告信息
     *
     * @param id 公告ID
     * @return 公告信息
     */
    public WeaRotaInfo selectWeaRotaInfoById(Long id);


    public List<WeaRotaInfo> selectWeaRotaInfoByDate(Date startDate, Date endDate);

    /**
     * 查询公告列表
     *
     * @param weaRotaInfo 公告信息
     * @return 公告集合
     */
    public List<WeaRotaInfo> selectWeaRotaInfoList(WeaRotaInfo weaRotaInfo);

    /**
     * 新增公告
     *
     * @param weaRotaInfo 公告信息
     * @return 结果
     */
    public int insertWeaRotaInfo(WeaRotaInfo weaRotaInfo);

    /**
     * 修改公告
     *
     * @param weaRotaInfo 公告信息
     * @return 结果
     */
    public int updateWeaRotaInfo(WeaRotaInfo weaRotaInfo);

    /**
     * 批量删除公告
     *
     * @param id 公告ID
     * @return 结果
     */
    public int deleteWeaRotaInfoById(Long id);

}
